@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # pylint: skip-file
 
 import copy
@@ -16,12 +17,13 @@ from bokeh.colors import RGB
 import bokeh.plotting as bpl
 from bokeh.plotting import figure
 from bokeh.layouts import row, column
-from bokeh.models import ColorBar, BasicTicker, LinearColorMapper, Legend
+from bokeh.models import ColorBar, BasicTicker, LinearColorMapper, Legend  # type: ignore
 from bokeh.io import show, output_notebook
-import ipyvolume as ipv
 from matplotlib.colors import LinearSegmentedColormap
 from matplotlib import cm
 from matplotlib.image import imsave
+import plotly.graph_objects as go  # type: ignore
+import plotly.express as px  # type: ignore
 
 
 def pandora_cmap():
@@ -277,7 +279,7 @@ def compare_2_disparities(
     second_fig.add_layout(legend, "below")
     second_fig.add_layout(color_bar, "right")
 
-    layout = column(row(first_fig, second_fig))
+    layout = column(row(first_fig, second_fig))  # type: ignore
 
     show(layout)
 
@@ -289,7 +291,7 @@ def compare_3_disparities_and_error(
     second_title: str,
     input_third_disp_map: xr.Dataset,
     third_title: str,
-    error_map: np.array,
+    error_map: np.ndarray,
     error_title: str,
 ) -> None:
     """
@@ -307,7 +309,7 @@ def compare_3_disparities_and_error(
     :param third_title: disparity map title
     :type third_title: str
     :param error_map: error map
-    :type error_map: np.array
+    :type error_map: np.ndarray
     :param error_title: error title
     :type error_title: str
     :return: none
@@ -418,13 +420,13 @@ def compare_3_disparities_and_error(
     error_fig.image(image=[np.flip(error_map, 0)], x=1, y=0, dw=dw, dh=dh, color_mapper=mapper_avec_opti)
     error_fig.add_layout(color_bar, "right")
 
-    layout = column(row(first_fig, second_fig), row(third_fig, error_fig))
+    layout = column(row(first_fig, second_fig), row(third_fig, error_fig))  # type: ignore
 
     show(layout)
 
 
 def compare_disparity_and_error(
-    input_first_disp_map: xr.Dataset, first_title: str, error_map: np.array, error_title: str
+    input_first_disp_map: xr.Dataset, first_title: str, error_map: np.ndarray, error_title: str
 ) -> None:
     """
     Show disparity map and error
@@ -433,7 +435,7 @@ def compare_disparity_and_error(
     :param title: disparity map title
     :type title: str
     :param error_map: error map
-    :type error_map: np.array
+    :type error_map: np.ndarray
     :param error_title: error title
     :type error_title: str
     :return: none
@@ -507,7 +509,7 @@ def compare_disparity_and_error(
     error_fig.add_layout(legend, "below")
     error_fig.add_layout(color_bar, "right")
 
-    layout = column(row(first_fig, error_fig))
+    layout = column(row(first_fig, error_fig))  # type: ignore
     show(layout)
 
 
@@ -566,13 +568,13 @@ def show_input_images(img_left: xr.Dataset, img_right: xr.Dataset) -> None:
         title="Anaglyph", width=width, height=height, x_range=left_fig.x_range, y_range=left_fig.y_range
     )
     anaglyph_fig.image_rgba(image=[np.flip(img, 0)], x=1, y=0, dw=dw, dh=dh)
-    layout = column(row(left_fig, right_fig, anaglyph_fig))
+    layout = column(row(left_fig, right_fig, anaglyph_fig))  # type: ignore
     show(layout)
 
 
 def get_error(
     left_disp_map: xr.Dataset, ground_truth: xr.Dataset, threshold: int = 1
-) -> Tuple[np.array, np.array, np.array, np.array, np.array]:
+) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
     """
     Return error map
 
@@ -583,12 +585,12 @@ def get_error(
     :param threshold: error threshold
     :type threshold: int
     :return: error_map, total_bad_percentage, mean_error, std_error, invalid_percentage
-    :rtype: Tuple[np.array,np.array,np.array,np.array,np.array]
+    :rtype: Tuple[np.ndarray,np.ndarray,np.ndarray,np.ndarray,np.ndarray]
     """
     total_bad_percentage, mean_error, std_error, invalid_percentage, error_map = compare_to_gt(
         left_disp_map, ground_truth, threshold, None
     )
-    return error_map, total_bad_percentage, mean_error, std_error, invalid_percentage
+    return error_map, total_bad_percentage, mean_error, std_error, invalid_percentage  # type:ignore
 
 
 def plot_1_cost_volume(cv: xr.Dataset, left_disp_map: xr.Dataset, title: str) -> None:
@@ -602,11 +604,11 @@ def plot_1_cost_volume(cv: xr.Dataset, left_disp_map: xr.Dataset, title: str) ->
     :return: none
     """
     print(title)
-    get_3D_cost_volume(cv, left_disp_map)
-    ipv.show()
+    fig = get_3D_cost_volume(cv, left_disp_map)
+    fig.show()
 
 
-def get_3D_cost_volume(cv: xr.Dataset, left_disp_map: xr.Dataset) -> None:
+def get_3D_cost_volume(cv: xr.Dataset, left_disp_map: xr.Dataset) -> go.Figure:
     """
     Plot 3d cost volume
 
@@ -624,28 +626,30 @@ def get_3D_cost_volume(cv: xr.Dataset, left_disp_map: xr.Dataset) -> None:
     Y = np.float32(Y)
     Z = left_disp_map["disparity_map"].data
 
-    color_disp = np.ravel(Z)
-    color_disp = color_disp - np.nanmin(color_disp)
-    color_disp = color_disp * 1.0 / np.nanmax(color_disp)
-    color_disp = np.repeat(color_disp[:, np.newaxis], 3, axis=1)
+    color_disp = [
+        [0, "rgb(255, 79, 100)"],
+        [0.25, "rgb(240, 50,73)"],
+        [0.5, "rgb(240, 240,240)"],
+        [0.75, "rgb(208,232,160)"],
+        [1.0, "rgb(57, 163, 80)"],
+    ]
+    df = {"cols": np.flipud(np.ravel(X)), "rows": np.ravel(Y), "disps": np.ravel(Z)}
 
-    fig = ipv.figure()
-    scatter = ipv.scatter(np.ravel(X), np.ravel(Y), np.ravel(Z), marker="point_2d", size=10, color=color_disp)
-    ipv.ylim(nb_rows, 0)
-    ipv.style.box_off()
-    ipv.style.use("minimal")
+    fig = px.scatter_3d(df, x="cols", y="rows", z="disps", color="disps", color_continuous_scale=color_disp)
 
-    return ipv.gcc()
+    fig.update_traces(marker=dict(size=0.5), selector=dict(mode="markers"))
+
+    return fig
 
 
-def add_mask(all_validity_mask: np.array, msk_type: int) -> np.array:
+def add_mask(all_validity_mask: np.ndarray, msk_type: int) -> np.ndarray:
     """
     Create mask for a given bit
 
     :param all_validity_mask: mask for all bits
-    :type all_validity_mask: np.array
+    :type all_validity_mask: np.ndarray
     :return: msk
-    :rtype: np.array
+    :rtype: np.ndarray
     """
     # Mask initialization to 0 (all valid)
     msk = np.full(all_validity_mask.shape, 0)
@@ -726,7 +730,7 @@ def add_validity_mask_to_dataset(input_disp_map: xr.Dataset) -> xr.Dataset:
 
 def compare_to_gt(
     disp_map: xr.Dataset, ground_truth: xr.Dataset, error_threshold: int, no_data_gt_value: float = None
-) -> Tuple[float, float, float, float, np.array]:
+) -> Tuple[float, float, float, float, np.ndarray]:
     """
     Compute difference between a disparity map (estimated by a stereo tool) and ground_truth.
     Point p is considered as an error if disp_map(p)-ground_truth(p) > threshold
