@@ -264,9 +264,9 @@ class AbstractRefinement:
                                     cv[row, col, dsp - 1],
                                     cv[row, col, dsp],
                                     cv[row, col, dsp + 1],
-                                ],
+                                ],  # type: ignore
                                 disp[row, col],
-                                measure,
+                                measure,  # type: ignore
                             )
 
                             disp[row, col] = disp[row, col] + (sub_disp / subpixel)
@@ -279,9 +279,10 @@ class AbstractRefinement:
 
         return itp_coeff, disp, mask
 
+    @staticmethod
     @abstractmethod
     @njit(cache=True)
-    def refinement_method(self, cost: np.ndarray, disp: float, measure: str) -> Tuple[float, float, int]:
+    def refinement_method(cost: np.ndarray, disp: float, measure: str) -> Tuple[float, float, int]:
         """
         Return the subpixel disparity and cost
 
@@ -360,9 +361,9 @@ class AbstractRefinement:
                                     cv[row, diagonal - 1, dsp + (1 * subpixel)],
                                     cv[row, diagonal, dsp],
                                     cv[row, diagonal + 1, dsp - (1 * subpixel)],
-                                ],
+                                ],  # type: ignore
                                 disp[row, col],
-                                measure,
+                                measure,  # type: ignore
                             )
 
                             disp[row, col] = disp[row, col] + (sub_disp / subpixel)
