@@ -34,8 +34,12 @@ from json_checker import Checker, And
 try:
     import graphviz  # pylint: disable=unused-import
     from transitions.extensions import GraphMachine as Machine
+
+    FLAG_GRAPHVIZ = True
 except ImportError:
-    from transitions import Machine
+    from transitions import Machine  # type: ignore
+
+    FLAG_GRAPHVIZ = False
 from transitions import MachineError
 
 from pandora import aggregation
@@ -124,44 +128,44 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
 
     _transitions_check = [
         {
-            "trigger": "matching_cost",
+            "trigger": "check_matching_cost",
             "source": "begin",
             "dest": "cost_volume",
             "before": "right_disp_map_check_conf",
             "after": "matching_cost_check_conf",
         },
         {
-            "trigger": "aggregation",
+            "trigger": "check_aggregation",
             "source": "cost_volume",
             "dest": "cost_volume",
             "after": "aggregation_check_conf",
         },
         {
-            "trigger": "optimization",
+            "trigger": "check_optimization",
             "source": "cost_volume",
             "dest": "cost_volume",
             "after": "optimization_check_conf",
         },
         {
-            "trigger": "disparity",
+            "trigger": "check_disparity",
             "source": "cost_volume",
             "dest": "disp_map",
             "after": "disparity_check_conf",
         },
         {
-            "trigger": "filter",
+            "trigger": "check_filter",
             "source": "disp_map",
             "dest": "disp_map",
             "after": "filter_check_conf",
         },
         {
-            "trigger": "refinement",
+            "trigger": "check_refinement",
             "source": "disp_map",
             "dest": "disp_map",
             "after": "refinement_check_conf",
         },
         {
-            "trigger": "validation",
+            "trigger": "check_validation",
             "source": "disp_map",
             "dest": "disp_map",
             "after": "validation_check_conf",
@@ -169,13 +173,13 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
         # For the check conf we define the destination of multiscale state as disp_map instead of begin
         # given the conditional change of state
         {
-            "trigger": "multiscale",
+            "trigger": "check_multiscale",
             "source": "disp_map",
             "dest": "disp_map",
             "after": "multiscale_check_conf",
         },
         {
-            "trigger": "cost_volume_confidence",
+            "trigger": "check_cost_volume_confidence",
             "source": "cost_volume",
             "dest": "cost_volume",
             "after": "cost_volume_confidence_check_conf",
@@ -186,10 +190,10 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
         self,
         img_left_pyramid: List[xr.Dataset] = None,
         img_right_pyramid: List[xr.Dataset] = None,
-        disp_min: Union[np.array, int] = None,
-        disp_max: Union[np.array, int] = None,
-        right_disp_min: Union[np.array, None] = None,
-        right_disp_max: Union[np.array, None] = None,
+        disp_min: Union[np.ndarray, int] = None,
+        disp_max: Union[np.ndarray, int] = None,
+        right_disp_min: Union[np.ndarray, None] = None,
+        right_disp_max: Union[np.ndarray, None] = None,
     ) -> None:
 
         """
@@ -206,13 +210,13 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type img_right_pyramid: xarray.Dataset
         :param disp_min: minimal disparity
-        :type disp_min: int or np.array
+        :type disp_min: int or np.ndarray
         :param disp_max: maximal disparity
-        :type disp_max: int or np.array
+        :type disp_max: int or np.ndarray
         :param right_disp_min: minimal disparity of the right image
-        :type right_disp_min: None or np.array
+        :type right_disp_min: None or np.ndarray
         :param right_disp_max: maximal disparity of the right image
-        :type right_disp_max: None or np.array
+        :type right_disp_max: None or np.ndarray
         :return: None
         """
         # Left image scale pyramid
@@ -224,21 +228,21 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
         # Right image
         self.right_img: xr.Dataset = None
         # Minimum disparity
-        self.disp_min: Union[np.array, int] = disp_min
+        self.disp_min: Union[np.ndarray, int] = disp_min
         # Maximum disparity
-        self.disp_max: Union[np.array, int] = disp_max
+        self.disp_max: Union[np.ndarray, int] = disp_max
         # Maximum disparity for the right image
-        self.right_disp_min: Union[np.array, None] = right_disp_min
+        self.right_disp_min: Union[np.ndarray, None] = right_disp_min
         # Minimum disparity for the right image
-        self.right_disp_max: Union[np.array, None] = right_disp_max
+        self.right_disp_max: Union[np.ndarray, None] = right_disp_max
         # User minimum disparity
-        self.dmin_user: Union[np.array, int] = None
+        self.dmin_user: Union[np.ndarray, int] = None
         # User maximum disparity
-        self.dmax_user: Union[np.array, int] = None
+        self.dmax_user: Union[np.ndarray, int] = None
         # User minimum disparity right
-        self.dmin_user_right: Union[np.array, None] = None
+        self.dmin_user_right: Union[np.ndarray, None] = None
         # User maximum disparity right
-        self.dmax_user_right: Union[np.array, None] = None
+        self.dmax_user_right: Union[np.ndarray, None] = None
 
         # Scale factor
         self.scale_factor: int = None
@@ -264,14 +268,25 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
         # Define avalaible states
         states_ = ["begin", "cost_volume", "disp_map"]
 
-        # Initialize a machine without any transition
-        Machine.__init__(
-            self,
-            states=states_,
-            initial="begin",
-            transitions=None,
-            auto_transitions=False,
-        )
+        if FLAG_GRAPHVIZ:
+            # Initialize a machine without any transition
+            Machine.__init__(
+                self,
+                states=states_,
+                initial="begin",
+                transitions=None,
+                auto_transitions=False,
+                use_pygraphviz=False,
+            )
+        else:
+            # Initialize a machine without any transition
+            Machine.__init__(
+                self,
+                states=states_,
+                initial="begin",
+                transitions=None,
+                auto_transitions=False,
+            )
 
         logging.getLogger("transitions").setLevel(logging.WARNING)
 
@@ -465,14 +480,14 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
         # Compute disparity range for the next scale level
         if self.right_disp_map != "accurate":
             self.disp_min, self.disp_max = multiscale_.disparity_range(
-                self.left_disparity, self.dmin_user, self.dmax_user
+                self.left_disparity, int(self.dmin_user), int(self.dmax_user)
             )
             # Set to None the disparity map for the next scale
             self.left_disparity = None
 
         else:
             self.disp_min, self.disp_max = multiscale_.disparity_range(
-                self.left_disparity, self.dmin_user, self.dmax_user
+                self.left_disparity, int(self.dmin_user), int(self.dmax_user)
             )
             # Set to None the disparity map for the next scale
             self.left_disparity = None
@@ -481,7 +496,7 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
             self.dmin_user_right = self.dmin_user_right * self.scale_factor
             self.dmax_user_right = self.dmax_user_right * self.scale_factor
             self.right_disp_min, self.right_disp_max = multiscale_.disparity_range(
-                self.right_disparity, self.dmin_user_right, self.dmax_user_right
+                self.right_disparity, int(self.dmin_user_right), int(self.dmax_user_right)
             )
             self.right_disparity = None
 
@@ -501,6 +516,11 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
         :type input_step: str
         :return: None
         """
+        # In case multiple confidence maps are computed, add its
+        # name to the indicator to distinguish the different maps
+        cfg[input_step]["indicator"] = ""
+        if len(input_step.split(".")) == 2:
+            cfg[input_step]["indicator"] = "." + input_step.split(".")[1]
         confidence_ = cost_volume_confidence.AbstractCostVolumeConfidence(**cfg[input_step])  # type: ignore
 
         logging.info("Confidence prediction...")
@@ -522,12 +542,12 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
         cfg: Dict[str, dict],
         left_img: xr.Dataset,
         right_img: xr.Dataset,
-        disp_min: Union[np.array, int],
-        disp_max: Union[np.array, int],
+        disp_min: Union[np.ndarray, int],
+        disp_max: Union[np.ndarray, int],
         scale_factor: Union[None, int] = None,
         num_scales: Union[None, int] = None,
-        right_disp_min: Union[None, np.array] = None,
-        right_disp_max: Union[None, np.array] = None,
+        right_disp_min: Union[None, np.ndarray] = None,
+        right_disp_max: Union[None, np.ndarray] = None,
     ) -> None:
         """
         Prepare the machine before running
@@ -545,17 +565,17 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
                 - msk (optional): 2D (row, col) xarray.DataArray
         :type right_img: xarray.Dataset
         :param disp_min: minimal disparity
-        :type disp_min: int or np.array
+        :type disp_min: int or np.ndarray
         :param disp_max: maximal disparity
-        :type disp_max: int or np.array
+        :type disp_max: int or np.ndarray
         :param scale_factor: scale factor for multiscale
         :type scale_factor: int or None
         :param num_scales: scales number for multiscale
         :type num_scales: int or None
-        :param disp_min_right: minimal disparity of the right image
-        :type disp_min_right: np.array or None
-        :param disp_max_right: maximal disparity of the right image
-        :type disp_max_right: np.array or None
+        :param right_disp_min: minimal disparity of the right image
+        :type right_disp_min: np.ndarray or None
+        :param right_disp_max: maximal disparity of the right image
+        :type right_disp_max: np.ndarray or None
         :return: None
         """
         # Mono-resolution processing by default if num_scales or scale_factor are not specified
@@ -577,16 +597,16 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
             self.current_scale = num_scales - 1
             # If multiscale, disparities can only be int.
             # Downscale disparities since the pyramid is processed from coarse to original size
-            self.disp_min = int(disp_min / (scale_factor ** self.num_scales))
-            self.disp_max = int(disp_max / (scale_factor ** self.num_scales))
+            self.disp_min = int(disp_min / (scale_factor**self.num_scales))
+            self.disp_max = int(disp_max / (scale_factor**self.num_scales))
             # User disparity
             self.dmin_user = self.disp_min
             self.dmax_user = self.disp_max
-            # If multiscale disparities can only be int, and right disparity can only be np.array, so right disparity
+            # If multiscale disparities can only be int, and right disparity can only be np.ndarray, so right disparity
             # can not be defined in the input conf
             # Right disparities
-            self.right_disp_min = -self.disp_max
-            self.right_disp_max = -self.disp_min
+            self.right_disp_min = -self.disp_max  # type: ignore
+            self.right_disp_max = -self.disp_min  # type: ignore
             # Right user disparity
             self.dmin_user_right = self.right_disp_min
             self.dmax_user_right = self.right_disp_max
@@ -605,8 +625,8 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
                 self.right_disp_min = right_disp_min
                 self.right_disp_max = right_disp_max
             else:
-                self.right_disp_min = -self.disp_max
-                self.right_disp_max = -self.disp_min
+                self.right_disp_min = -self.disp_max  # type: ignore
+                self.right_disp_max = -self.disp_min  # type: ignore
 
         # Initiate output disparity datasets
         self.left_disparity = xr.Dataset()
@@ -832,10 +852,13 @@ class PandoraMachine(Machine):  # pylint:disable=too-many-instance-attributes
                 # filter
                 # trigger and give the configuration of filter.1
 
+                # change input name to avoid may_[step] repetition in transitions packages
+                check_input = "check_" + input_step
+
                 if len(input_step.split(".")) != 1:
-                    self.trigger(input_step.split(".")[0], cfg, input_step)
+                    self.trigger(check_input.split(".")[0], cfg, input_step)
                 else:
-                    self.trigger(input_step, cfg, input_step)
+                    self.trigger(check_input, cfg, input_step)
 
             except (MachineError, KeyError, AttributeError):
                 logging.error("A problem occurs during Pandora checking. Be sure of your sequencement")
